==> nodegit-0.2.4.tgz: package/src/filter_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/filter_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitFilterList::GitFilterList(git_filter_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitFilterList::~GitFilterList() {
   }

  void GitFilterList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("FilterList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("FilterList"), _constructor_template);
  }

  NAN_METHOD(GitFilterList::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitFilterList cannot be instantiated.");
     }

    GitFilterList* object = new GitFilterList(static_cast<git_filter_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitFilterList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitFilterList::constructor_template)->NewInstance(2, argv));
  }

  git_filter_list *GitFilterList::GetValue() {
    return this->raw;
  }

  git_filter_list **GitFilterList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitFilterList::constructor_template;

==> nodegit-0.2.5.tgz: package/src/filter_list.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/filter_list.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitFilterList::GitFilterList(git_filter_list *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitFilterList::~GitFilterList() {
   }

  void GitFilterList::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("FilterList"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("FilterList"), _constructor_template);
  }

  NAN_METHOD(GitFilterList::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitFilterList cannot be instantiated.");
     }

    GitFilterList* object = new GitFilterList(static_cast<git_filter_list *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitFilterList::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitFilterList::constructor_template)->NewInstance(2, argv));
  }

  git_filter_list *GitFilterList::GetValue() {
    return this->raw;
  }

  git_filter_list **GitFilterList::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitFilterList::constructor_template;
